@@ -430,20 +430,20 @@ class TTvec(object):
                         if ((i-1) in notpassidxs_old) and (not self.ttcross_rs[i] == MAXRANK[i]):
                             self.ttcross_rs[i] += 1
                             notpassidxs.append(i-1)
-                except Exception as e:
-                    # If the size of the tensor A is small and can be fully stored, store it with also the last Js/Is used in ttcross
-                    if self.A.size <= 2*1e7/8: # Limit set to approx 20mb of file size
-                        import pickle as pkl
-                        FILENAME = "TensorToolbox.log"
-                        outdic = dict({'A': self.A[tuple([slice(None,None,None) for i in range(d)])],
-                                       'Js': self.ttcross_Js,
-                                       'Is': self.ttcross_Is,
-                                       'Jinit': self.ttcross_Jinit})
-                        outfile = open(FILENAME,'wb')
-                        pkl.dump(outdic,outfile)
-                        outfile.close()
-                        print "TTvec: Log file stored"
                 except:
+                    # For big problems, even with small dimensionality, this logging is unpractical
+                    # # If the size of the tensor A is small and can be fully stored, store it with also the last Js/Is used in ttcross
+                    # if self.A.size <= 2*1e7/8: # Limit set to approx 20mb of file size
+                    #     import pickle as pkl
+                    #     FILENAME = "TensorToolbox.log"
+                    #     outdic = dict({'A': self.A[tuple([slice(None,None,None) for i in range(d)])],
+                    #                    'Js': self.ttcross_Js,
+                    #                    'Is': self.ttcross_Is,
+                    #                    'Jinit': self.ttcross_Jinit})
+                    #     outfile = open(FILENAME,'wb')
+                    #     pkl.dump(outdic,outfile)
+                    #     outfile.close()
+                    #     print "TTvec: Log file stored"
                     raise
                 else:
                     TTapprox = TTvec( Gnew )
