@@ -26,20 +26,6 @@
 # Author: Daniele Bigoni
 #
 
-"""
-
-Created on Tue Jul 2 11:00:00 2013
-
-@author: Daniele Bigoni (dabi@imm.dtu.dk)
-
-@version: 0.1
-
-DABITensor is the collection of tools for Tensor decomposition and arithmetic
-
-@copyright: 2014 The Technical University of Denmark
-
-"""
-
 from multilinalg import *
 
 __author__ = "Daniele Bigoni"
