@@ -28,16 +28,17 @@ import numpy.linalg as npla
 import scipy.sparse as sp
 import scipy.sparse.linalg as spla
 import itertools
-from matplotlib import pyplot as plt
 import time
 
 import TensorToolbox as DT
 import TensorToolbox.multilinalg as mla
 from aux import bcolors
 
-plt.close('all')
 PLOTTING = False
 
+if PLOTTING:
+    from matplotlib import pyplot as plt
+
 def print_ok(string):
     print bcolors.OKGREEN + "[SUCCESS] " + string + bcolors.ENDC
 
