@@ -26,7 +26,6 @@ import sys
 import numpy as np
 import numpy.linalg as npla
 import itertools
-from matplotlib import pyplot as plt
 import time
 
 import TensorToolbox as DT
@@ -34,10 +33,12 @@ import TensorToolbox.multilinalg as mla
 
 from aux import bcolors
 
-plt.close('all')
 RUNTESTS = [0,1,2,3,4,5,7]
 PLOTTING = False
 
+if PLOTTING:
+    from matplotlib import pyplot as plt
+
 def print_ok(string):
     print bcolors.OKGREEN + "[SUCCESS] " + string + bcolors.ENDC
 
